@@ -1,8 +1,10 @@
-`read.crn` <- function(fname, header=NULL, encoding = getOption("encoding"))
+`read.crn` <- function(fname, header=NULL, encoding = getOption("encoding"),
+                       long = TRUE)
 {
     ## Open the data file for reading
     con <- file(fname, encoding = encoding)
     on.exit(close(con))
+    long2 <- isTRUE(long)
     if(is.null(header)){
         ## Try to determine if the file has a header. This is failable.
         ## Find out if an ITRDB header (3 lines) in file
@@ -41,11 +43,30 @@
     }
     if(nchar(dat1) < 10)
         stop("first data line ends before col 10")
-    yrcheck <- as.numeric(substr(dat1, 7, 10))
+    decade_pos <- 7L
+    yrcheck <- as.numeric(substr(dat1, decade_pos, 10L))
     if(is.null(yrcheck) || length(yrcheck)!=1 || is.na(yrcheck) ||
        yrcheck < -1e04 || yrcheck > 1e04)
-        stop(gettextf("cols %d-%d of first data line not a year", 7, 10,
-                      domain="R-dplR"))
+        stop(gettextf("cols %d-%d of first data line not a year",
+                      decade_pos, 10L, domain="R-dplR"), domain = NA)
+    if (long2) {
+        year_now <- 1900 + as.POSIXlt(Sys.Date())$year
+        if (yrcheck > year_now) {
+            tmp_pos <-
+                regexpr(" *-[[:digit:]]+$", substr(dat1, 2, 10))[[1L]] + 1L
+            if (tmp_pos > 0L) {
+                decade_pos <- tmp_pos
+                message(gettextf("Using cols %d-%d for decade field",
+                                 decade_pos, 10L, domain = "R-dplR"),
+                        domain = NA)
+            } else {
+                warning(gettextf("year %d is in the future",
+                                 yrcheck, domain = "R-dplR"),
+                        domain = NA)
+            }
+        }
+    }
+    decade_fix <- decade_pos - 7L
     ## Look at last line to determine if Chronology Statistics are present
     ## if nchar <=63 then there is a stats line
     nlines <- length(readLines(con, n=-1))
@@ -54,11 +75,9 @@
     ## Do nothing. read.fwf closes (and destroys ?!?) the file connection
     on.exit()
     ## Get chron stats if needed
-    chron.stats <- read.fwf(con, c(6, 4, 6, 6, 6, 7, 9, 9, 10),
+    chron.stats <- read.fwf(con, c(6 + decade_fix, 4 - decade_fix,
+                                   6, 6, 6, 7, 9, 9, 10),
                             skip=nlines-1, strip.white=TRUE)
-    ## Unintuitively, the connection object seems to have been destroyed
-    ## by the previous read.fwf.  We need to create a new one.
-    con <- file(fname, encoding = encoding)
     ## If columns 3 in chron.stats is an integer then there is no
     ## statistics line
     if(is.numeric(chron.stats[[3]]) &&
@@ -68,25 +87,44 @@
               "MeanRWI", "IndicesSum", "IndicesSS", "MaxSeries")
         cat(gettext("Embedded chronology statistics\n", domain="R-dplR"))
         print(chron.stats)
-        ## Really read file
-        dat <- read.fwf(con, c(6, 4, rep(c(4, 3), 10)),
-                        skip=skip.lines, n=nlines-skip.lines-1,
-                        colClasses=c("character", rep("integer", 21)),
-                        strip.white=TRUE)
+        n_dat <- nlines - skip.lines - 1
     } else {
-        ## Really read file
-        dat <- read.fwf(con, c(6, 4, rep(c(4, 3), 10)),
-                        skip=skip.lines, n=nlines-skip.lines,
-                        colClasses=c("character", rep("integer", 21)),
-                        strip.white=TRUE)
+        n_dat <- nlines - skip.lines
     }
-    ## Remove any blank lines at the end of the file, for instance
-    dat <- dat[!is.na(dat[[2]]), , drop=FALSE] # requires non-NA year
+    while (decade_fix >= -5L) {
+        ## We need to create a new connection object.
+        con <- file(fname, encoding = encoding)
+        ## Really read file
+        dat <- read.fwf(con, c(6 + decade_fix, 4 - decade_fix,
+                               rep(c(4, 3), 10)),
+                        skip = skip.lines, n = n_dat,
+                        colClasses = c("character", rep("integer", 21)),
+                        strip.white = TRUE)
+        ## Remove any blank lines at the end of the file, for instance
+        dat <- dat[!is.na(dat[[2]]), , drop=FALSE] # requires non-NA year
 
-    series <- dat[[1]]
-    series.ids <- unique(series)
-    decade.yr <- dat[[2]]
-    nseries <- length(series.ids)
+        series <- dat[[1]]
+        series.ids <- unique(series)
+        decade.yr <- dat[[2]]
+        nseries <- length(series.ids)
+        if (!long2 || nseries == 1L) {
+            break
+        } else {
+            sign_table <- table(sign(diff(decade.yr)))
+            if (length(sign_table) == 1L ||
+                sum(sign_table) - max(sign_table) <= nseries - 1L) {
+                break
+            }
+            decade_fix <- decade_fix - 1L
+        }
+    }
+    decade_pos2 <- decade_fix + 7L
+    if (decade_pos2 != decade_pos) {
+        message(gettextf("Using cols %d-%d for decade field",
+                         decade_pos2, 10L, domain = "R-dplR"),
+                domain = NA)
+    }
+    
     cat(sprintf(ngettext(nseries,
                          "There is %d series\n",
                          "There are %d series\n",
